# [PATCH] diff: try lazy read of config only once

3 messages from 2008-01-04 to 2008-01-04. Participants: Jeff King, Junio C Hamano.
Thread: https://gitlist.dev/t/11465

## Jeff King, 2008-01-04 08:31

Subject: [PATCH] diff: try lazy read of config only once
Message-ID: <20080104083116.GA3354@coredump.intra.peff.net>
URL: https://gitlist.dev/e/20080104083116.GA3354%40coredump.intra.peff.net

```
The function read_config_if_needed used a list pointer to
determined whether it had already been called. However, if
the user had no diff drivers, the function would repeatedly
read the config (typically once per diffed file).

Instead, let's use a signal variable so that we read it only
once (note that we may actually still read it an extra time,
since the config may already have been read outside of this
function). This reduces the cost of

  git-whatchanged -p >/dev/null

from 34 seconds to 33 seconds.

Signed-off-by: Jeff King <peff@peff.net>
---
This are might be changed from the fallout of the other mail I just
sent, but I wanted to at least mention it. The speedup is not terribly
significant, but it just seems stupid to parse the config file thousands
of times. And I suspect on slow-I/O systems (like Cygwin) that it might
make more of a difference.

 diff.c |    5 +++++
 1 files changed, 5 insertions(+), 0 deletions(-)

diff --git a/diff.c b/diff.c
index 5bdc111..f6a8515 100644
--- a/diff.c
+++ b/diff.c
@@ -61,10 +61,15 @@ static struct ll_diff_driver {
 
 static void read_config_if_needed(void)
 {
+	static int done = 0;
+	if (done)
+		return;
+
 	if (!user_diff_tail) {
 		user_diff_tail = &user_diff;
 		git_config(git_diff_ui_config);
 	}
+	done = 1;
 }
 
 /*
-- 
1.5.4.rc2.1122.g6954-dirty

```

## Junio C Hamano, 2008-01-04 08:36

Subject: Re: [PATCH] diff: try lazy read of config only once
Message-ID: <7v1w8ym1g6.fsf@gitster.siamese.dyndns.org>
URL: https://gitlist.dev/e/7v1w8ym1g6.fsf%40gitster.siamese.dyndns.org
In-Reply-To: <20080104083116.GA3354@coredump.intra.peff.net>

```
Thanks.  I think you can lose "if (!user_diff_tail)" there as
well.

```

## Jeff King, 2008-01-04 08:40

Subject: Re: [PATCH] diff: try lazy read of config only once
Message-ID: <20080104084024.GA3522@coredump.intra.peff.net>
URL: https://gitlist.dev/e/20080104084024.GA3522%40coredump.intra.peff.net
In-Reply-To: <7v1w8ym1g6.fsf@gitster.siamese.dyndns.org>

```
On Fri, Jan 04, 2008 at 12:36:57AM -0800, Junio C Hamano wrote:

> Thanks.  I think you can lose "if (!user_diff_tail)" there as
> well.

Oops, yes. Please mark it up when you apply.

-Peff

```
